@@ -1,11 +1,10 @@
 # demo: regression
 # author: Daniel Adler
-# $Id: regression.r 376 2005-08-03 23:58:47Z dadler $
+# $Id: regression.r 406 2005-08-22 00:03:18Z dmurdoch $
 
 rgl.demo.regression <- function(n=100,xa=3,za=8,xb=0.02,zb=0.01,xlim=c(0,100),zlim=c(0,100)) {
 
-  rgl.clear()
-  rgl.clear(type="lights")
+  rgl.clear("all")
   rgl.bg(sphere = TRUE, color = c("black", "green"), lit = FALSE, size=2, alpha=0.2, back = "lines")
   rgl.light()
   rgl.bbox()
