@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: api.cpp 417 2006-02-04 12:33:31Z dmurdoch $
+// $Id: api.cpp 463 2006-06-26 10:44:23Z murdoch $
 
 #include "lib.hpp"
 
@@ -78,7 +78,7 @@ void rgl_quit(int* successptr)
 
 void rgl_dev_open(int* successptr)
 {
-  *successptr = as_success( deviceManager->openDevice() );
+  *successptr = as_success( deviceManager && deviceManager->openDevice() );
 }
 
 
@@ -93,9 +93,7 @@ void rgl_dev_close(int* successptr)
 
   Device* device;
 
-  device = deviceManager->getCurrentDevice();
-
-  if (device) {
+  if (deviceManager && (device = deviceManager->getCurrentDevice())) {
 
     device->close();
     success = RGL_SUCCESS;
@@ -111,9 +109,7 @@ void rgl_dev_bringtotop(int* successptr, int* stay)
 
   Device* device;
 
-  device = deviceManager->getCurrentDevice();
-
-  if (device) {
+  if (deviceManager && (device = deviceManager->getCurrentDevice())) {
 
     device->bringToTop(*stay);
     success = RGL_SUCCESS;
@@ -133,8 +129,12 @@ void rgl_dev_bringtotop(int* successptr, int* stay)
 
 void rgl_dev_getcurrent(int* successptr, int* idptr)
 {
-  *idptr = deviceManager->getCurrent();
-  *successptr = RGL_SUCCESS;
+  if (deviceManager) {
+    *idptr = deviceManager->getCurrent();
+    *successptr = RGL_SUCCESS;
+  } else {
+    *successptr = RGL_FAIL;
+  }
 }
 
 //
@@ -149,7 +149,7 @@ void rgl_dev_getcurrent(int* successptr, int* idptr)
 void rgl_dev_setcurrent(int* successptr, int* idata)
 {
   int id = idata[0];
-  *successptr = as_success ( deviceManager->setCurrent(id) );
+  *successptr = as_success ( deviceManager && deviceManager->setCurrent(id) );
 }
 
 
@@ -173,10 +173,11 @@ static Material currentMaterial(Color(1.0f,1.0f,1.0f),Color(1.0f,0.0f,0.0f));
 void rgl_clear(int* successptr, int *idata)
 {
   int success = RGL_SUCCESS;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
   int num = idata[0];
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
+
     for (int i=1; success && i<=num; i++) {
       TypeID stackTypeID = (TypeID) idata[i];
 
@@ -202,9 +203,9 @@ void rgl_clear(int* successptr, int *idata)
 void rgl_pop(int* successptr, int* idata)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getCurrentDevice();
+  Device* device;
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getCurrentDevice())) {
 
     TypeID stackTypeID = (TypeID) idata[0];
  
@@ -231,8 +232,10 @@ void rgl_bg(int* successptr, int* idata)
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getAnyDevice();
-  if (device) {
+  Device* device;
+  
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
+
     bool sphere    = as_bool( idata[0] );
     int  fogtype   = idata[1];
 
@@ -252,9 +255,9 @@ void rgl_light ( int* successptr, int* idata, double* ddata )
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if ( device ) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
     bool  viewpoint_rel = as_bool( idata[0] );
 
@@ -281,20 +284,21 @@ void rgl_viewpoint(int* successptr, int* idata, double* ddata)
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
     float theta	      = static_cast<float>( ddata[0] );
     float phi	      = static_cast<float>( ddata[1] );
     float fov         = static_cast<float>( ddata[2] );
-    float zoom        = static_cast<float>( ddata[3] - 1.0 )/static_cast<float>(VIEWPOINT_MAX_ZOOM-1);
-
+    float zoom        = static_cast<float>( ddata[3] );
+    Vec3  scale       = Vec3( ddata[4], ddata[5], ddata[6] );
+    
     int   interactive = idata[0];
     int   polar       = idata[1];
     
-    if (polar) success = as_success( device->add( new Viewpoint(PolarCoord(theta, phi), fov, zoom, interactive) ) );
-    else       success = as_success( device->add( new Viewpoint(ddata + 4, fov, zoom, interactive) ) );
+    if (polar) success = as_success( device->add( new Viewpoint(PolarCoord(theta, phi), fov, zoom, scale, interactive) ) );
+    else       success = as_success( device->add( new Viewpoint(ddata + 7, fov, zoom, scale, interactive) ) );
 
   }
 
@@ -304,14 +308,14 @@ void rgl_viewpoint(int* successptr, int* idata, double* ddata)
 void rgl_getZoom(int* successptr, double* zoom)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if ( device ) {
     RGLView* rglview = device->getRGLView();
     Scene* scene = rglview->getScene();
     Viewpoint* viewpoint = scene->getViewpoint();
     *zoom = viewpoint->getZoom();
-    *zoom = 1.0f+(*zoom)* ((float)(VIEWPOINT_MAX_ZOOM-1)) ;
     success = RGL_SUCCESS;
   }
   *successptr = success;
@@ -320,13 +324,14 @@ void rgl_getZoom(int* successptr, double* zoom)
 void rgl_setZoom(int* successptr, double* zoom)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if ( device ) {
     RGLView* rglview = device->getRGLView();
     Scene* scene = rglview->getScene();
     Viewpoint* viewpoint = scene->getViewpoint();
-    viewpoint->setZoom((*zoom - 1.0f)/((float)(VIEWPOINT_MAX_ZOOM-1)));
+    viewpoint->setZoom( *zoom );
     rglview->update();
     success = RGL_SUCCESS;
   }
@@ -336,9 +341,10 @@ void rgl_setZoom(int* successptr, double* zoom)
 void rgl_getFOV(int* successptr, double* fov)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if ( device ) {
     RGLView* rglview = device->getRGLView();
     Scene* scene = rglview->getScene();
     Viewpoint* viewpoint = scene->getViewpoint();
@@ -351,9 +357,10 @@ void rgl_getFOV(int* successptr, double* fov)
 void rgl_setFOV(int* successptr, double* fov)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if ( device ) {
     RGLView* rglview = device->getRGLView();
     Scene* scene = rglview->getScene();
     Viewpoint* viewpoint = scene->getViewpoint();
@@ -364,12 +371,39 @@ void rgl_setFOV(int* successptr, double* fov)
   *successptr = success;
 }
 
+void rgl_getIgnoreExtent(int* successptr, int* ignoreExtent)
+{
+  int success = RGL_FAIL;
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
+
+    *ignoreExtent = device->getIgnoreExtent();
+    success = RGL_SUCCESS;
+  }
+  *successptr = success;
+}
+
+void rgl_setIgnoreExtent(int* successptr, int* ignoreExtent)
+{
+  int success = RGL_FAIL;
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
+
+    device->setIgnoreExtent(*ignoreExtent);
+    success = RGL_SUCCESS;
+  }
+  *successptr = success;
+}
+
 void rgl_getSkipRedraw(int* successptr, int* skipRedraw)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if ( device ) {
     *skipRedraw = device->getSkipRedraw();
     success = RGL_SUCCESS;
   }
@@ -379,9 +413,10 @@ void rgl_getSkipRedraw(int* successptr, int* skipRedraw)
 void rgl_setSkipRedraw(int* successptr, int* skipRedraw)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if ( device ) {
     device->setSkipRedraw(*skipRedraw);
     success = RGL_SUCCESS;
   }
@@ -391,30 +426,31 @@ void rgl_setSkipRedraw(int* successptr, int* skipRedraw)
 void rgl_primitive(int* successptr, int* idata, double* vertex)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if ( device ) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
     int   type    = idata[0];
     int   nvertex = idata[1];
-
+    int   ignoreExtent = device->getIgnoreExtent();
+    
     SceneNode* node;
 
     switch(type) {
     case 1: // RGL_POINTS:
-      node = new PointSet( currentMaterial, nvertex, vertex);
+      node = new PointSet( currentMaterial, nvertex, vertex, ignoreExtent);
       break;
     case 2: // RGL_LINES:
-      node = new LineSet( currentMaterial, nvertex, vertex);
+      node = new LineSet( currentMaterial, nvertex, vertex, ignoreExtent);
       break;
     case 3: // RGL_TRIANGLES:
-      node = new TriangleSet( currentMaterial, nvertex, vertex);
+      node = new TriangleSet( currentMaterial, nvertex, vertex, ignoreExtent);
       break;
     case 4: // RGL_QUADS:
-      node = new QuadSet( currentMaterial, nvertex, vertex);
+      node = new QuadSet( currentMaterial, nvertex, vertex, ignoreExtent);
       break;
     case 5: // RGL_LINE_STRIP:
-      node = new LineStripSet( currentMaterial, nvertex, vertex);
+      node = new LineStripSet( currentMaterial, nvertex, vertex, ignoreExtent);
       break;
     default:
       node = NULL;
@@ -435,13 +471,15 @@ void rgl_surface(int* successptr, int* idata, double* x, double* z, double* y, i
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if (device) {
     int nx         = idata[0];
     int nz         = idata[1];
 
-    success = as_success( device->add( new Surface(currentMaterial, nx, nz, x, z, y, coords, *orientation) ) );
+    success = as_success( device->add( new Surface(currentMaterial, nx, nz, x, z, y, coords, *orientation,
+    						   device->getIgnoreExtent()) ) );
 
   }
 
@@ -452,13 +490,15 @@ void rgl_spheres(int* successptr, int* idata, double* vertex, double* radius)
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if (device) {
     int nvertex = idata[0];
     int nradius = idata[1];
 
-    success = as_success( device->add( new SphereSet(currentMaterial, nvertex, vertex, nradius, radius) ) );
+    success = as_success( device->add( new SphereSet(currentMaterial, nvertex, vertex, nradius, radius,
+    						     device->getIgnoreExtent()) ) );
   }
 
   *successptr = success;
@@ -468,13 +508,15 @@ void rgl_sprites(int* successptr, int* idata, double* vertex, double* radius)
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if (device) {
     int nvertex = idata[0];
     int nradius = idata[1];
 
-    success = as_success( device->add( new SpriteSet(currentMaterial, nvertex, vertex, nradius, radius) ) );
+    success = as_success( device->add( new SpriteSet(currentMaterial, nvertex, vertex, nradius, radius,
+    						     device->getIgnoreExtent()) ) );
   }
 
   *successptr = success;
@@ -525,16 +567,68 @@ void rgl_material(int *successptr, int* idata, char** cdata, double* ddata)
   *successptr = RGL_SUCCESS;
 }
 
+void rgl_getcolorcount(int* count)
+{
+  *count = currentMaterial.colors.getLength();
+}
+
+void rgl_getmaterial(int *successptr, int* idata, char** cdata, double* ddata)
+{
+  Material& mat = currentMaterial;
+  unsigned int i,j;
+  
+  idata[1] = mat.lit ? 1 : 0;
+  idata[2] = mat.smooth ? 1 : 0;
+  idata[3] = (int) mat.front;
+  idata[4] = (int) mat.back;
+  idata[5] = mat.fog ? 1 : 0;
+  idata[6] = 0; /* mat.texture.type; */
+  idata[7] = 0; /* mat.texture.mipmap ? 1 : 0; */
+  idata[8] = 0; /* mat.texture.minfilter; */
+  idata[9] = 0; /* mat.texture.magfilter; */
+
+  idata[11] = (int) mat.ambient.getRedub();
+  idata[12] = (int) mat.ambient.getGreenub();
+  idata[13] = (int) mat.ambient.getBlueub();
+  idata[14] = (int) mat.specular.getRedub();
+  idata[15] = (int) mat.specular.getGreenub();
+  idata[16] = (int) mat.specular.getBlueub();  
+  idata[17] = (int) mat.emission.getRedub();
+  idata[18] = (int) mat.emission.getGreenub();
+  idata[19] = (int) mat.emission.getBlueub();
+  idata[20] = 0; /* mat.texture.envmap ? 1 : 0; */
+  for (i=0, j=21; (i < mat.colors.getLength()) && (i < (unsigned int)idata[0]); i++) {
+    idata[j++] = (int) mat.colors.getColor(i).getRedub();
+    idata[j++] = (int) mat.colors.getColor(i).getGreenub();
+    idata[j++] = (int) mat.colors.getColor(i).getBlueub();
+  }
+  idata[0] = i;
+
+  ddata[0] = (double) mat.shininess;
+  ddata[1] = (double) mat.size;
+  
+  if (mat.colors.hasAlpha()) {
+    for (i=0, j=2; (i < mat.colors.getLength()) && (i < (unsigned int)idata[10]); i++) 
+      ddata[j++] = (double) mat.colors.getColor(i).getAlphaf();
+    idata[10] = i;
+  } else 
+    idata[10] = 0;
+  
+  *successptr = RGL_SUCCESS;
+}
+
 void rgl_texts(int* successptr, int* idata, double* adj, char** text, double* vertex)
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
-  if (device) {
     int ntext   = idata[0];
 
-    success = as_success( device->add( new TextSet(currentMaterial, ntext, text, vertex, *adj) ) );
+    success = as_success( device->add( new TextSet(currentMaterial, ntext, text, vertex, *adj,
+    						   device->getIgnoreExtent()) ) );
   }
 
   *successptr = success;
@@ -549,9 +643,9 @@ void rgl_bbox(int* successptr,
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
     int   xticks     =        idata[0];
     int   yticks     =        idata[1];
@@ -565,12 +659,14 @@ void rgl_bbox(int* successptr,
     float yunit      = (float) ddata[1];
     float zunit      = (float) ddata[2];
     float marklen    = (float) ddata[3];
+    float expand     = (float) ddata[4];    
+
 
     AxisInfo xaxis(xticks, xat, xtext, xlen, xunit);
     AxisInfo yaxis(yticks, yat, ytext, ylen, yunit);
     AxisInfo zaxis(zticks, zat, ztext, zlen, zunit);
 
-    success = as_success( device->add( new BBoxDeco(currentMaterial, xaxis, yaxis, zaxis, marklen, (bool) marklen_rel ) ) );
+    success = as_success( device->add( new BBoxDeco(currentMaterial, xaxis, yaxis, zaxis, marklen, (bool) marklen_rel, expand ) ) );
   }
 
   *successptr = success;
@@ -580,9 +676,9 @@ void rgl_snapshot(int* successptr, int* idata, char** cdata)
 {
   int success = RGL_FAIL;
 
-  Device* device = deviceManager->getCurrentDevice();
+  Device* device;
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getCurrentDevice())) {
 
     int   format   = idata[0];
     char* filename = cdata[0];
@@ -599,12 +695,15 @@ void rgl_user2window(int* successptr, int* idata, double* point, double* pixel,
   int success = RGL_FAIL;
   GLdouble* vertex = pixel;
   int columns = idata[0];
+  GLint viewport[4];
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if ( device ) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
+  
+  	for (int i=0; i<4; i++) viewport[i] = view[i];
   	for (int i=0; i<columns; i++) {
-		gluProject(point[0],point[1],point[2],model,proj,view,
+		gluProject(point[0],point[1],point[2],model,proj,viewport,
 		vertex,vertex+1,vertex+2);
 		vertex[0] /= view[2];
 		vertex[1] /= view[3];
@@ -622,14 +721,17 @@ void rgl_window2user(int* successptr, int* idata, double* point, double* pixel,
   int success = RGL_FAIL;
   GLdouble* vertex = point;
   int columns = idata[0];
+  GLint viewport[4];
 
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if ( device ) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
+  
+    	for (int i=0; i<4; i++) viewport[i] = view[i];
   	for (int i=0; i<columns; i++) {
 	        pixel[0] *= view[2];
 	        pixel[1] *= view[3];
-		gluUnProject(pixel[0],pixel[1],pixel[2],model,proj,view,
+		gluUnProject(pixel[0],pixel[1],pixel[2],model,proj,viewport,
 		vertex,vertex+1,vertex+2);
 		pixel += 3;
 		vertex += 3;
@@ -643,9 +745,10 @@ void rgl_window2user(int* successptr, int* idata, double* point, double* pixel,
 void rgl_getMouseMode(int* successptr, int *button, int* mode)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
+  
  	RGLView* rglview = device->getRGLView();
   	*mode = static_cast<int>( rglview->getMouseMode(*button) );
     	success = RGL_SUCCESS;
@@ -657,9 +760,10 @@ void rgl_getMouseMode(int* successptr, int *button, int* mode)
 void rgl_setMouseMode(int* successptr, int* button, int* mode)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
+  
  	RGLView* rglview = device->getRGLView();
 	rglview->setMouseMode(*button, (MouseModeID)(*mode));
 
@@ -675,9 +779,7 @@ void rgl_selectstate(int* successptr, int* selectstate, double* locations)
 	int success = RGL_FAIL;
 	Device* device;
 
-	device = deviceManager->getAnyDevice();
-
-  	if (device){
+	if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
 		RGLView* rglview = device->getRGLView();
 		
@@ -699,9 +801,9 @@ void rgl_selectstate(int* successptr, int* selectstate, double* locations)
 void rgl_setselectstate(int* successptr, int *idata)
 {
   int success = RGL_FAIL;
-  Device* device = deviceManager->getAnyDevice();
+  Device* device;
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
     MouseSelectionID selectState = (MouseSelectionID) idata[0];
 	RGLView* rglview = device->getRGLView();
@@ -717,9 +819,9 @@ void rgl_setselectstate(int* successptr, int *idata)
 void rgl_getUserMatrix(int* successptr, double* userMatrix)
 {
 	int success = RGL_FAIL;
-  	Device* device = deviceManager->getAnyDevice();
+  	Device* device;
 
-  	if (device) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
 		RGLView* rglview = device->getRGLView();
 		rglview->getUserMatrix(userMatrix);
@@ -735,9 +837,9 @@ void rgl_setUserMatrix(int* successptr, double* userMatrix)
 {
 
 	int success = RGL_FAIL;
-  	Device* device = deviceManager->getAnyDevice();
+  	Device* device;
 
-  	if (device) {
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
 		RGLView* rglview = device->getRGLView();
 		rglview->setUserMatrix(userMatrix);
@@ -750,12 +852,48 @@ void rgl_setUserMatrix(int* successptr, double* userMatrix)
 
 }
 
-void rgl_getModelMatrix(int* successptr, double* modelMatrix)
+void rgl_getScale(int* successptr, double* scale)
 {
 	int success = RGL_FAIL;
   	Device* device = deviceManager->getAnyDevice();
 
-	if (device){
+  	if (device) {
+
+		RGLView* rglview = device->getRGLView();
+		rglview->getScale(scale);
+
+    	success = RGL_SUCCESS;
+
+  	}
+
+  *successptr = success;
+}
+
+void rgl_setScale(int* successptr, double* scale)
+{
+
+	int success = RGL_FAIL;
+  	Device* device = deviceManager->getAnyDevice();
+
+  	if (device) {
+
+		RGLView* rglview = device->getRGLView();
+		rglview->setScale(scale);
+
+		success = RGL_SUCCESS;
+
+  	}
+
+  *successptr = success;
+
+}
+
+void rgl_getModelMatrix(int* successptr, double* modelMatrix)
+{
+	int success = RGL_FAIL;
+  	Device* device;
+
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
 		RGLView* rglview = device->getRGLView();
 		for (int i=0; i<16; i++) {
@@ -770,9 +908,9 @@ void rgl_getModelMatrix(int* successptr, double* modelMatrix)
 void rgl_getProjMatrix(int* successptr, double* projMatrix)
 {
 	int success = RGL_FAIL;
-  	Device* device = deviceManager->getAnyDevice();
+  	Device* device;
 
-	if (device){
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
 		RGLView* rglview = device->getRGLView();
 		for (int i=0; i<16; i++) {
@@ -787,9 +925,9 @@ void rgl_getProjMatrix(int* successptr, double* projMatrix)
 void rgl_getViewport(int* successptr, int* viewport)
 {
 	int success = RGL_FAIL;
-  	Device* device = deviceManager->getAnyDevice();
+  	Device* device;
 
-	if (device){
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
 		RGLView* rglview = device->getRGLView();
 		for (int i=0; i<4; i++) {
@@ -805,9 +943,9 @@ void rgl_postscript(int* successptr, int* idata, char** cdata)
 {
   int success = RGL_FAIL;
  
-  Device* device = deviceManager->getCurrentDevice();
+  Device* device;
 
-  if (device) {
+  if (deviceManager && (device = deviceManager->getCurrentDevice())) {
 
     int   format   = idata[0];
     char* filename = cdata[0];
@@ -822,9 +960,9 @@ void rgl_postscript(int* successptr, int* idata, char** cdata)
 void rgl_getBoundingbox(int* successptr, double* bboxvec)
 {
 	int success = RGL_FAIL;
-  	Device* device = deviceManager->getAnyDevice();
+  	Device* device;
 
-	if (device){
+  if (deviceManager && (device = deviceManager->getAnyDevice())) {
 
 	  const AABox& bbox = device->getScene()->getBoundingBox();
 	  bboxvec[0] = bbox.vmin.x;
