@@ -6,14 +6,14 @@
 // ---------------------------------------------------------------------------
 #include "osxgui.hpp"
 // ---------------------------------------------------------------------------
-#include <stdio.h>
+#include <R.h>
 #include <cassert>
 // ---------------------------------------------------------------------------
 namespace lib {
 // ---------------------------------------------------------------------------
 void printMessage(const char* message)
 {
-  printf(message); printf("\n");
+  REprintf("RGL: %s\n", message);
 }
 // ---------------------------------------------------------------------------
 double getTime()
